<?php
use CRM_Areas_ExtensionUtil as E;

/**
 * Collection of upgrade steps.
 */
class CRM_Areas_Upgrader extends CRM_Areas_Upgrader_Base {

  public function install() {
    $this->executeSqlFile('sql/install.sql');
  }

  public function uninstall() {
   $this->executeSqlFile('sql/uninstall.sql');
   // Custom groups uninstall loop.
   $customgroups = civicrm_api3('CustomGroup', 'get', [
      'name' => ['IN' => [
        'contact_areas',
        'group_areas',
      ]],
      'return' => ['id']
    ]);
    $customgroup_ids = array_keys($customgroups['values'] ?? []);
    if ($customgroup_ids) {
      // Found one or more of our custom groups.
      // Lookup fields for these and delete those first.
      $customfields = civicrm_api3('CustomField', 'get', [
        'custom_group_id' => ['IN' => $customgroup_ids],
        'return'          => ['id'],
      ]);
      foreach (array_keys($customfields['values'] ?? []) as $customfield_id) {
        civicrm_api3('CustomField', 'delete', ['id' => $customfield_id]);
      }

      // Now delete the groups themselves.
      foreach ($customgroup_ids as $customgroup_id) {
        civicrm_api3('CustomGroup', 'delete', ['id' => $customgroup_id]);
      }
    }
    $optiongroups = civicrm_api3('OptionGroup', 'get', [
      'name' => ['IN' => [
        'contact_areas',
        'group_areas',
      ]],
      'return' => ['id']
    ]);
    $optiongroup_ids = array_keys($optiongroups['values'] ?? []);
    if ($optiongroup_ids) {
      // Found one or more of our option groups.
      // Lookup values for these and delete those first.
      $optionvalues = civicrm_api3('OptionValue', 'get', [
        'option_group_id' => ['IN' => $optiongroup_ids],
        'return'          => ['id'],
      ]);
      foreach (array_keys($optionvalues['values'] ?? []) as $optionvalue_id) {
        civicrm_api3('OptionValue', 'delete', ['id' => $optionvalue_id]);
      }

      // Now delete the groups themselves.
      foreach ($optiongroup_ids as $optiongroup_id) {
        civicrm_api3('OptionGroup', 'delete', ['id' => $optiongroup_id]);
      }
    }
  }

}
